@@ -1,6 +1,7 @@
 #' Get The Plant List families.
 #'
 #' @export
+#' @param ... (list) Curl options passed on to \code{\link[httr]{GET}}
 #' @details Requires an internet connection in order to connect to www.theplantlist.org.
 #' @return Returns a \code{data.frame} including the names of all families indexed
 #' by The Plant List, and the major groups into which they fall (i.e. Angiosperms,
@@ -11,14 +12,13 @@
 #' # Get a data.frame of plant families, with the group name (Angiosperms, etc.)
 #' head( tpl_families() )
 #' }
-
-tpl_families <- function() {
-  temp <- GET('http://www.theplantlist.org/1.1/browse/-/')
-  temp <- htmlParse(content(temp, "text"), encoding = "UTF-8")
-  families <- xpathSApply(temp, "//ul[@id='nametree']//a", xmlValue)
-  groups <- as.character(factor(basename(dirname(xpathSApply(temp,
-                                                "//ul[@id='nametree']//a",
-                                                xmlGetAttr, 'href'))),
+tpl_families <- function(...) {
+  temp <- GET('http://www.theplantlist.org/1.1/browse/-/', ...)
+  stop_for_status(temp)
+  temp <- xml2::read_html(con_utf8(temp), encoding = "UTF-8")
+  families <- xml2::xml_text(xml2::xml_find_all(temp, "//ul[@id='nametree']//a"))
+  groups <- as.character(factor(basename(dirname(
+    xml2::xml_attr(xml2::xml_find_all(temp, "//ul[@id='nametree']//a"), "href"))),
                    levels = c('A', 'B', 'G', 'P'),
                    labels = c('Angiosperms', 'Bryophytes',
                             'Gymnosperms', 'Pteridophytes')))
